import React from 'react';
import List from './List';
import IIIFParser from '../services/iiif-parser';
import { connect } from 'react-redux';
import * as actions from '../actions';
import PropTypes from 'prop-types';

var iiifParser = new IIIFParser();

var ListItem = function ListItem(props) {
  var item = props.item;

  var childCanvases = iiifParser.getChildCanvases(item);
  var subMenu = item.items && item.items.length > 0 && childCanvases.length === 0 ? React.createElement(List, { items: item.items }) : null;

  var handleClick = function handleClick(e) {
    e.stopPropagation();
    e.preventDefault();
    props.navItemClick(e.target.href);
  };

  var renderListItem = function renderListItem() {
    var label = item.label || 'Canvas item with no label';

    if (childCanvases.length > 0) {
      return childCanvases.map(function (canvasItem) {
        return React.createElement(
          'a',
          { key: canvasItem.id, href: canvasItem.id, onClick: handleClick },
          label
        );
      });
    } else {
      return label;
    }
  };

  return React.createElement(
    'li',
    null,
    renderListItem(),
    subMenu
  );
};

ListItem.propTypes = process.env.NODE_ENV !== "production" ? {
  key: PropTypes.string,
  item: PropTypes.object.isRequired
} : {};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    navItemClick: function navItemClick(url) {
      return dispatch(actions.navItemClick(url));
    }
  };
};

export default connect(null, mapDispatchToProps)(ListItem);