'use strict';

exports.__esModule = true;
exports.fetchManifestRequest = fetchManifestRequest;
exports.fetchManifestSuccess = fetchManifestSuccess;
exports.fetchManifestFailure = fetchManifestFailure;
exports.playerInitialized = playerInitialized;
exports.navItemClick = navItemClick;
exports.getRemoteManifest = getRemoteManifest;

var _types = require('./types');

var types = _interopRequireWildcard(_types);

var _api = require('../services/api');

var api = _interopRequireWildcard(_api);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function fetchManifestRequest(url) {
  return {
    type: types.FETCH_MANIFEST_REQUEST,
    payload: url
  };
}

function fetchManifestSuccess(manifest) {
  return {
    type: types.FETCH_MANIFEST_SUCCESS,
    payload: manifest
  };
}

function fetchManifestFailure(error) {
  return {
    type: types.FETCH_MANIFEST_FAILURE,
    payload: error
  };
}

function playerInitialized(player) {
  return {
    type: types.MEJS_PLAYER_INITIALIZED,
    payload: player
  };
}

function navItemClick(url) {
  return {
    type: types.NAV_ITEM_CLICK,
    payload: url
  };
}

function getRemoteManifest(url) {
  return function (dispatch) {
    dispatch(fetchManifestRequest(url));

    return api.fetchManifest(url).then(function (response) {
      if (response.error) {
        return dispatch(fetchManifestFailure(response.error));
      }
      return dispatch(fetchManifestSuccess(response));
    });
  };
}